import React, { Fragment, useEffect, useState } from 'react';
import { Text, Static } from 'ink';
import Spinner from 'ink-spinner';
import { Error } from './Error.js';
async function deletePipelinesForProject(projectId, props, reportProgress) {
    const { startDate, days, listPipelines, filterPipelinesByDate, deletePipeline } = props;
    const pipelines = await listPipelines(projectId);
    const oldPipelines = filterPipelinesByDate({ startDate, olderThanDays: days, pipelines });
    return oldPipelines.map((pipeline) => {
        return props.deleteQueue.add(() => {
            reportProgress(`Deleting pipeline with id ${pipeline.id} for project ${projectId}`);
            return deletePipeline(projectId, pipeline);
        });
    });
}
async function deletePipelines(props, reportProgress) {
    const { deleteQueue } = props;
    try {
        const projectDeletions = props.projectIds.map((projectId) => {
            return deletePipelinesForProject(projectId, props, reportProgress);
        });
        const deleteTasks = await Promise.all(projectDeletions);
        const { deleteQueue } = props;
        reportProgress(`${deleteQueue.size} pipelines found`);
        deleteQueue.start();
        await Promise.all(deleteTasks.flat());
        return deleteQueue.onIdle();
    }
    catch (error) {
        deleteQueue.clear();
        throw error;
    }
}
export const App = (props) => {
    const [deleteProgress, setDeleteProgress] = useState(['']);
    const [isDone, setDone] = useState(false);
    const [deletePipelinesError, setDeletePipelinesError] = useState();
    useEffect(() => {
        deletePipelines(props, (text) => {
            setDeleteProgress((currentDeleteProgress) => [...currentDeleteProgress, text]);
        })
            .then(() => {
            setDone(true);
        })
            .catch(setDeletePipelinesError);
    }, [props]);
    if (deletePipelinesError !== undefined) {
        const message = props.showStackTraces ? deletePipelinesError.stack : deletePipelinesError.message;
        return React.createElement(Error, { exit: props.exit },
            "There was an error while deleting the pipelines: ",
            message);
    }
    return (React.createElement(Fragment, null,
        React.createElement(Static, { items: deleteProgress }, (text) => React.createElement(Text, { key: text }, text)),
        React.createElement(Text, null,
            !isDone && React.createElement(Spinner, null),
            isDone && React.createElement(Text, { color: "green" }, "Pipelines deleted"))));
};
//# sourceMappingURL=App.js.map