import { URL } from 'node:url';
import { parseISO, differenceInDays } from 'date-fns';
export function listPipelines({ getRequest, gitlabUrl, accessToken }) {
    return (projectId) => {
        const escapedProjectId = encodeURIComponent(projectId);
        const url = new URL(`/api/v4/projects/${escapedProjectId}/pipelines`, gitlabUrl);
        url.searchParams.set('per_page', '100');
        return getRequest(url.toString(), accessToken);
    };
}
export function deletePipeline({ deleteRequest, gitlabUrl, accessToken, }) {
    return async (projectId, pipeline) => {
        const escapedProjectId = encodeURIComponent(projectId);
        const escapedPipelineId = encodeURIComponent(pipeline.id);
        const url = new URL(`/api/v4/projects/${escapedProjectId}/pipelines/${escapedPipelineId}`, gitlabUrl);
        await deleteRequest(url.toString(), accessToken);
    };
}
function isOlderThanDays(startDate, pipelineDate, days) {
    return differenceInDays(startDate, pipelineDate) > days;
}
export const filterPipelinesByDate = ({ pipelines, startDate, olderThanDays }) => {
    return pipelines.filter((pipeline) => {
        const pipelineDate = parseISO(pipeline.updated_at);
        return isOlderThanDays(startDate, pipelineDate, olderThanDays);
    });
};
//# sourceMappingURL=gitlab.js.map